Scriptname FNIS Hidden
; =============================================================================
; FNIS Versioning =============================================================
; created by: jbezorg@yaiws.com
; =============================================================================

; =============================================================================
; FNIS.VersionToString() ======================================================
; =============================================================================
; This function returns the concatenation of Major & minor versions as well
; as the version flags. A period (full stop) delimiter is used.
;
; @param bool abCreature - check FNIS Creature Pack version info. defaults to
;        false and FNIS Behavior version info.
; @return string - concatenated version info
string function VersionToString( bool abCreature = false ) global
	actor kPlayer = Game.GetPlayer()

	if abCreature
		return kPlayer.GetAnimationVariableInt("FNISCreatureMajor") as String \
		+ "." + kPlayer.GetAnimationVariableInt("FNISCreatureMinor1") as String \
		+ "." + kPlayer.GetAnimationVariableInt("FNISCreatureMinor2") as String \
		+ "." + kPlayer.GetAnimationVariableInt("FNISCreatureFlags") as String
	else
		return kPlayer.GetAnimationVariableInt("FNISmajor") as String \
		+ "." + kPlayer.GetAnimationVariableInt("FNISMinor1") as String \
		+ "." + kPlayer.GetAnimationVariableInt("FNISMinor2") as String \
		+ "." + kPlayer.GetAnimationVariableInt("FNISFlags") as String
	endIf
endFunction

; =============================================================================
; FNIS.VersionCompare() =======================================================
; =============================================================================
; Compares the major, minor1 & minor2 versions ints passed as attributes to the
; current version of FNIS installed. This function returns an int reflecting
; the result of the comparision between Major, Minor1 & Minor2 version numbers.
; Note that FNISFlags values are not compared.
;
;  0 = Both versions match.
;  1 = The installed version is newer/greater than the compared version.
; -1 = The installed version is older/less than the compared version.
;
; @param int iCompMajor  - Major version
; @param int iCompMinor1 - Mminor1 version
; @param int iCompMinor2 - Mminor2 version
; @param bool abCreature - check FNIS Creature Pack version info. defaults to
;        false and FNIS Behavior version info.
; @return int - 0 
int function VersionCompare( int iCompMajor, int iCompMinor1, int iCompMinor2, bool abCreature = false ) global
	int iCharPos
	int iInstMajor
	int iInstMinor1
	int iInstMinor2
	
	actor kPlayer = Game.GetPlayer()

	if abCreature
		iInstMajor  = kPlayer.GetAnimationVariableInt("FNISCreatureMajor")
		iInstMinor1 = kPlayer.GetAnimationVariableInt("FNISCreatureMinor1")
		iInstMinor2 = kPlayer.GetAnimationVariableInt("FNISCreatureMinor2")
	else
		iInstMajor  = kPlayer.GetAnimationVariableInt("FNISmajor")
		iInstMinor1 = kPlayer.GetAnimationVariableInt("FNISMinor1")
		iInstMinor2 = kPlayer.GetAnimationVariableInt("FNISMinor2")
	endIf

	if iInstMajor == iCompMajor
		if iInstMinor1 == iCompMinor1
			if iInstMinor2 == iCompMinor2
				return 0
			elseIf iInstMinor2 > iCompMinor2
				return 1
			else
				return -1
			endIf
		elseIf iInstMinor1 > iCompMinor1
			return 1
		else
			return -1
		endIf
	elseIf iInstMajor > iCompMajor
		return 1
	else
		return -1
	endIf
endFunction

; =============================================================================
; call FNIS.GetMajor() ========================================================
; =============================================================================
; Major changes and upgrades
;
; @param bool abCreature - check FNIS Creature Pack version info. defaults to
;        false and FNIS Behavior version info.
; @return int - major version
int function GetMajor( bool abCreature = false ) global
	actor kPlayer = Game.GetPlayer()

	if abCreature
		return kPlayer.GetAnimationVariableInt("FNISCreatureMajor")
	else
		return kPlayer.GetAnimationVariableInt("FNISmajor")
	endIf
endFunction

; =============================================================================
; call FNIS.GetMinor1() =======================================================
; =============================================================================
; Functional enhancements
;
; @param bool abCreature - check FNIS Creature Pack version info. defaults to
;        false and FNIS Behavior version info.
; @return int - minor1 version
int function GetMinor1( bool abCreature = false ) global
	actor kPlayer = Game.GetPlayer()

	if abCreature
		return kPlayer.GetAnimationVariableInt("FNISCreatureMinor1")
	else
		return kPlayer.GetAnimationVariableInt("FNISMinor1")
	endIf
endFunction

; =============================================================================
; call FNIS.GetMinor2() =======================================================
; =============================================================================
; Bug fixes
;
; @param bool abCreature - check FNIS Creature Pack version info. defaults to
;        false and FNIS Behavior version info.
; @return int - minor2 version
int function GetMinor2( bool abCreature = false ) global
	actor kPlayer = Game.GetPlayer()

	if abCreature
		return kPlayer.GetAnimationVariableInt("FNISCreatureMinor2")
	else
		return kPlayer.GetAnimationVariableInt("FNISMinor2")
	endIf
endFunction

; =============================================================================
; call FNIS.GetFlags() ========================================================
; =============================================================================
; Version flags.
; 0 = Pre-alpha
; 1 = Alpha
; 2 = Beta
; 3 = Release
;
; @param bool abCreature - check FNIS Creature Pack version info. defaults to
;        false and FNIS Behavior version info.
; @return int - minor2 version
int function GetFlags( bool abCreature = false ) global
	actor kPlayer = Game.GetPlayer()

	if abCreature
		return kPlayer.GetAnimationVariableInt("FNISCreatureFlags")
	else
		return kPlayer.GetAnimationVariableInt("FNISflags")
	endIf
endFunction

; =============================================================================
; call FNIS.IsAlpha() =========================================================
; =============================================================================
; Returns true if the installed FNIS version is flagged as an alpha.
;
; @param bool abCreature - check FNIS Creature Pack version info. defaults to
;        false and FNIS Behavior version info.
; @return bool
Bool function IsAlpha( bool abCreature = false ) global
	actor kPlayer = Game.GetPlayer()

	if abCreature
		return kPlayer.GetAnimationVariableInt("FNISCreatureFlags") == 1
	else
		return kPlayer.GetAnimationVariableInt("FNISflags") == 1
	endIf
endFunction

; =============================================================================
; call FNIS.IsBeta() ==========================================================
; =============================================================================
; Returns true if the installed FNIS version is flagged as an beta.
;
; @param bool abCreature - check FNIS Creature Pack version info. defaults to
;        false and FNIS Behavior version info.
; @return bool
Bool function IsBeta( bool abCreature = false ) global
	actor kPlayer = Game.GetPlayer()

	if abCreature
		return kPlayer.GetAnimationVariableInt("FNISCreatureFlags") == 2
	else
		return kPlayer.GetAnimationVariableInt("FNISflags") == 2
	endIf
endFunction

; =============================================================================
; call FNIS.IsRelease() =======================================================
; =============================================================================
; Returns true if the installed FNIS version is flagged as a stable release.
;
; @param bool abCreature - check FNIS Creature Pack version info. defaults to
;        false and FNIS Behavior version info.
; @return bool
Bool function IsRelease( bool abCreature = false ) global
	actor kPlayer = Game.GetPlayer()

	if abCreature
		return kPlayer.GetAnimationVariableInt("FNISCreatureFlags") == 3
	else
		return kPlayer.GetAnimationVariableInt("FNISflags") == 3
	endIf
endFunction
